@@ -5,6 +5,7 @@ import numpy as np
 import matplotlib
 import matplotlib.pyplot as plt
 import seaborn as sns
+from scipy.stats import norm
 
 def EOQ(demand, mean, STD, C, Ce, Cs, Ct):
   Qs=math.sqrt(2*Ct*demand/Ce)
@@ -105,7 +106,7 @@ def IOCT(TimeOrderShipped, TimeOrderReceived, NumberofOrdersShipped):
   return r
   #print("Internal Order Cycle Time: " + str(r))
 
-def printLineplotQtyByMonth(file,product_number):
+def lineplotQtyByMonth(file,product_number):
     sales = pd.read_csv(file)
     sales['ref'] = sales['ref'].astype('category')
     sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
@@ -119,7 +120,7 @@ def printLineplotQtyByMonth(file,product_number):
     plt.figure(figsize=(20,9))
     sns.lineplot(data=sales_qty, x='date',y='quantity').set_title(product_number)
     
-def printLineplotTotalCostByMonth(file,product_number):
+def lineplotTotalCostByMonth(file,product_number):
     sales = pd.read_csv(file)
     sales['ref'] = sales['ref'].astype('category')
     sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
@@ -134,7 +135,7 @@ def printLineplotTotalCostByMonth(file,product_number):
     plt.figure(figsize=(20,9))
     sns.lineplot(data=sales_qty, x='date',y='total_cost').set_title(product_number)
     
-def printLineplotTotalSalesByMonth(file,product_number):
+def lineplotTotalSalesByMonth(file,product_number):
     sales = pd.read_csv(file)
     sales['ref'] = sales['ref'].astype('category')
     sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
@@ -149,7 +150,7 @@ def printLineplotTotalSalesByMonth(file,product_number):
     plt.figure(figsize=(20,9))
     sns.lineplot(data=sales_qty, x='date',y='total_sales').set_title(product_number)
 
-def printLineplotAverageCostByMonth(file,product_number):
+def lineplotAverageCostByMonth(file,product_number):
     sales = pd.read_csv(file)
     sales['ref'] = sales['ref'].astype('category')
     sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
@@ -163,7 +164,7 @@ def printLineplotAverageCostByMonth(file,product_number):
     plt.figure(figsize=(20,9))
     sns.lineplot(data=sales_qty, x='date',y='cost').set_title(product_number)
     
-def printLineplotAverageSalesPriceByMonth(file,product_number):
+def lineplotAverageSalesPriceByMonth(file,product_number):
     sales = pd.read_csv(file)
     sales['ref'] = sales['ref'].astype('category')
     sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
@@ -175,4 +176,38 @@ def printLineplotAverageSalesPriceByMonth(file,product_number):
     sales_qty = sales_qty.resample('M').mean()
     sales_qty = sales_qty.reset_index()
     plt.figure(figsize=(20,9))
-    sns.lineplot(data=sales_qty, x='date',y='price').set_title(product_number)
\ No newline at end of file
+    sns.lineplot(data=sales_qty, x='date',y='price').set_title(product_number)
+    
+def basicSafetyStock(file,productNumber,safetyDays,leadTimeinDays):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales = sales.loc[sales['product_number'] == productNumber]
+    sales_qty = sales.set_index(["date"])
+    sales_qty = sales_qty.reset_index()
+    avg_sales = sales_qty.quantity.mean()
+    safety_stock = avg_sales*safetyDays
+    reorder_point = safety_stock+avg_sales*leadTimeinDays
+    print("Safety Stock: "+str(safety_stock))
+    print("Reorder Point: "+str(reorder_point))
+    
+def safetyStockwtServiceRate(file,productNumber,serviceRate,leadTimeInDays):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    sales = sales.loc[sales['product_number'] == productNumber]
+    sales_qty = sales.set_index(["date"])
+    sales_qty = sales_qty.reset_index()
+    sales_qty = sales_qty[['quantity']]
+    avg_sales = sales_qty.quantity.mean()
+    std = sales_qty.std()
+    servZ = norm.ppf(serviceRate)
+    LT_sqrt = math.sqrt(leadTimeInDays/30)
+    safety_stock = servZ*std*LT_sqrt
+    reorder_point = safety_stock+avg_sales*leadTimeInDays
+    print("Safety Stock: "+str(safety_stock))
+    print("Reorder Point: "+str(reorder_point))
\ No newline at end of file
